Coverage for curator/validators/logconfig.py: 0%

1"""Logging Schema definition"""

2 from voluptuous import Optional, Schema

3 from curator.defaults import logging_defaults

4

5 def logging():

6 """

7 Pulls value from :py:func:`~.curator.defaults.logging_defaults.config_logging`

8

9 :returns: ``{Optional('logging'): logging_defaults.config_logging()}``

10 :rtype: :py:class:`~.voluptuous.schema_builder.Schema`

11 """

12 return Schema({Optional('logging'): logging_defaults.config_logging()})